# icron
crontab, cron, schedule

just a copy of [schedule](https://schedule.readthedocs.io/)
but according to its [FAQ](https://schedule.readthedocs.io/en/stable/faq.html#frequently-asked-questions) add [run_continuously](https://github.com/mrhwick/schedule/blob/master/schedule/__init__.py) 
